import 'package:plugin_platform_interface/plugin_platform_interface.dart';

import 'color_system_method_channel.dart';

abstract class ColorSystemPlatform extends PlatformInterface {
  /// Constructs a ColorSystemPlatform.
  ColorSystemPlatform() : super(token: _token);

  static final Object _token = Object();

  static ColorSystemPlatform _instance = MethodChannelColorSystem();

  /// The default instance of [ColorSystemPlatform] to use.
  ///
  /// Defaults to [MethodChannelColorSystem].
  static ColorSystemPlatform get instance => _instance;

  /// Platform-specific implementations should set this with their own
  /// platform-specific class that extends [ColorSystemPlatform] when
  /// they register themselves.
  static set instance(ColorSystemPlatform instance) {
    PlatformInterface.verifyToken(instance, _token);
    _instance = instance;
  }

  Future<String?> getPlatformVersion() {
    throw UnimplementedError('platformVersion() has not been implemented.');
  }
}
